--- old/usr/src/uts/common/inet/tcp/tcp_socket.c	2012-07-24 09:52:55.023591606 +0000
+++ new/usr/src/uts/common/inet/tcp/tcp_socket.c	2012-07-24 09:52:55.071973372 +0000
@@ -54,12 +54,16 @@
 static int	tcp_listen(sock_lower_handle_t, int, cred_t *);
 static int	tcp_connect(sock_lower_handle_t, const struct sockaddr *,
 		    socklen_t, sock_connid_t *, cred_t *);
+static int	tcp_getpeername(sock_lower_handle_t, struct sockaddr *,
+		    socklen_t *, cred_t *);
+static int	tcp_getsockname(sock_lower_handle_t, struct sockaddr *,
+		    socklen_t *, cred_t *);
 static int	tcp_getsockopt(sock_lower_handle_t, int, int, void *,
 		    socklen_t *, cred_t *);
 static int	tcp_setsockopt(sock_lower_handle_t, int, int, const void *,
 		    socklen_t, cred_t *);
 static int	tcp_sendmsg(sock_lower_handle_t, mblk_t *, struct nmsghdr *,
-		    cred_t *cr);
+		    cred_t *);
 static int	tcp_shutdown(sock_lower_handle_t, int, cred_t *);
 static void	tcp_clr_flowctrl(sock_lower_handle_t);
 static int	tcp_ioctl(sock_lower_handle_t, int, intptr_t, int, int32_t *,
@@ -131,6 +135,9 @@
 	conn_t *lconnp, *econnp;
 	tcp_t *listener, *eager;
 
+	/* All Solaris components should pass a cred for this operation. */
+	ASSERT(cr != NULL);
+
 	/*
 	 * KSSL can move a socket from one listener to another, in which
 	 * case `lproto_handle' points to the new listener. To ensure that
@@ -334,7 +341,7 @@
 }
 
 /* ARGSUSED3 */
-int
+static int
 tcp_getpeername(sock_lower_handle_t proto_handle, struct sockaddr *addr,
     socklen_t *addrlenp, cred_t *cr)
 {
@@ -352,7 +359,7 @@
 }
 
 /* ARGSUSED3 */
-int
+static int
 tcp_getsockname(sock_lower_handle_t proto_handle, struct sockaddr *addr,
     socklen_t *addrlenp, cred_t *cr)
 {
@@ -377,6 +384,9 @@
 
 	ASSERT(connp->conn_upper_handle != NULL);
 
+	/* All Solaris components should pass a cred for this operation. */
+	ASSERT(cr != NULL);
+
 	error = proto_opt_check(level, option_name, *optlen, &max_optbuf_len,
 	    tcp_opt_obj.odb_opt_des_arr,
 	    tcp_opt_obj.odb_opt_arr_cnt,
@@ -424,6 +434,10 @@
 	int		error;
 
 	ASSERT(connp->conn_upper_handle != NULL);
+
+	/* All Solaris components should pass a cred for this operation. */
+	ASSERT(cr != NULL);
+
 	/*
 	 * Entering the squeue synchronously can result in a context switch,
 	 * which can cause a rather sever performance degradation. So we try to
@@ -752,6 +766,7 @@
 {
 	conn_t		*connp;
 	boolean_t	isv6 = family == AF_INET6;
+
 	if (type != SOCK_STREAM || (family != AF_INET && family != AF_INET6) ||
 	    (proto != 0 && proto != IPPROTO_TCP)) {
 		*errorp = EPROTONOSUPPORT;
@@ -765,7 +780,7 @@
 
 	/*
 	 * Put the ref for TCP. Ref for IP was already put
-	 * by ipcl_conn_create. Also Make the conn_t globally
+	 * by ipcl_conn_create. Also make the conn_t globally
 	 * visible to walkers
 	 */
 	mutex_enter(&connp->conn_lock);
